@@ -2,4 +2,4 @@
 from .config import EntityConfig, entity_registry, register_entity
 from .version import __version__
 from .tasks import SyncEntitiesTask
-from .models import Entity, EntityRelationship, turn_on_syncing, turn_off_syncing, sync_entities
+from .models import Entity, EntityKind, EntityRelationship, turn_on_syncing, turn_off_syncing, sync_entities
