@@ -1,17 +1,18 @@
 from itertools import compress
 
+from activatable_model import BaseActivatableModel, ActivatableManager, ActivatableQuerySet
 from django.contrib.contenttypes import generic
 from django.contrib.contenttypes.models import ContentType
 from django.db import models
 from django.db.models import Count
 from django.db.models.signals import post_save, post_delete, m2m_changed
 from jsonfield import JSONField
-from manager_utils import ManagerUtilsManager, ManagerUtilsQuerySet, post_bulk_operation
+from manager_utils import post_bulk_operation, ManagerUtilsManager
 
 from entity import entity_registry
 
 
-class EntityQuerySet(ManagerUtilsQuerySet):
+class EntityQuerySet(ActivatableQuerySet):
     """
     Provides additional queryset filtering abilities.
     """
@@ -116,9 +117,9 @@ class EntityQuerySet(ManagerUtilsQuerySet):
         return self.prefetch_related(*relationships_to_cache)
 
 
-class EntityManager(ManagerUtilsManager):
+class AllEntityManager(ActivatableManager):
     """
-    Provides additional entity-wide filtering abilities.
+    Provides additional entity-wide filtering abilities over all of the entity objects.
     """
     def get_queryset(self):
         return EntityQuerySet(self.model)
@@ -131,10 +132,11 @@ class EntityManager(ManagerUtilsManager):
 
     def delete_for_obj(self, entity_model_obj):
         """
-        Delete the entity associated with a model object.
+        Delete the entities associated with a model object.
         """
         return self.filter(
-            entity_type=ContentType.objects.get_for_model(entity_model_obj), entity_id=entity_model_obj.id).delete()
+            entity_type=ContentType.objects.get_for_model(entity_model_obj), entity_id=entity_model_obj.id).delete(
+            force=True)
 
     def active(self):
         """
@@ -192,6 +194,15 @@ class EntityManager(ManagerUtilsManager):
         return self.get_queryset().cache_relationships(cache_super=cache_super, cache_sub=cache_sub)
 
 
+class ActiveEntityManager(AllEntityManager):
+    """
+    The default 'objects' on the Entity model. This manager restricts all Entity queries to happen over active
+    entities.
+    """
+    def get_queryset(self):
+        return EntityQuerySet(self.model).active()
+
+
 class EntityKindManager(ManagerUtilsManager):
     """
     Provides additional filtering for entity kinds.
@@ -215,7 +226,7 @@ class EntityKind(models.Model):
         return self.display_name
 
 
-class Entity(models.Model):
+class Entity(BaseActivatableModel):
     """
     Describes an entity and its relevant metadata. Also defines if the entity is active. Filtering functions
     are provided that mirror the filtering functions in the Entity model manager.
@@ -225,11 +236,11 @@ class Entity(models.Model):
 
     # The generic entity
     entity_id = models.IntegerField()
-    entity_type = models.ForeignKey(ContentType)
+    entity_type = models.ForeignKey(ContentType, on_delete=models.PROTECT)
     entity = generic.GenericForeignKey('entity_type', 'entity_id')
 
     # The entity kind
-    entity_kind = models.ForeignKey(EntityKind)
+    entity_kind = models.ForeignKey(EntityKind, on_delete=models.PROTECT)
 
     # Metadata about the entity, stored as JSON
     entity_meta = JSONField(null=True)
@@ -237,7 +248,8 @@ class Entity(models.Model):
     # True if this entity is active
     is_active = models.BooleanField(default=True, db_index=True)
 
-    objects = EntityManager()
+    objects = ActiveEntityManager()
+    all_objects = AllEntityManager()
 
     class Meta:
         unique_together = ('entity_id', 'entity_type', 'entity_kind')
